@@ -7,7 +7,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2013-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2013-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -19,29 +19,32 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2010-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2010-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  *
- * @property string   $id               The device id.
- * @property string   $deviceType       The device type string.
- * @property string   $clientType       The client name, if available.
- * @property integer  $rwstatus         The RemoteWipe status - a
- *                                      Horde_ActiveSync::RWSTATUS_* constant.
- * @property string   $userAgent        The device's user agent string.
- * @property string   $user             The userid for the current device account.
- * @property array    $supported        The SUPPORTED data sent from this device.
- * @property string   $policykey        The current policykey, if provisioned.
- * @property array    $properties       The device properties, sent in DEVICEINFO,
- *                                      along with any custom properties set.
- * @property string   $announcedVersion The most last EAS supported versions
- *                                      announced to the device.
- * @property integer  $multiplex        Bitmask describing collections that this
- *                                      device does not support user created
- *                                      folders for, therefore all sources must
- *                                      be multiplexed together. Masks are
- *                                      the MULTIPLEX_* constants.
- * @property boolean   $blocked         True if device has been marked as blocked.
+ * @property string  $id               The device id.
+ * @property string  $deviceType       The device type string.
+ * @property string  $clientType       The client name, if available.
+ * @property integer $rwstatus         The RemoteWipe status - a
+ *                                     Horde_ActiveSync::RWSTATUS_* constant.
+ * @property string  $userAgent        The device's user agent string.
+ * @property string  $user             The userid for the current device
+ *                                     account.
+ * @property array   $supported        The SUPPORTED data sent from this device.
+ * @property string  $policykey        The current policykey, if provisioned.
+ * @property array   $properties       The device properties, sent in
+ *                                     DEVICEINFO, along with any custom
+ *                                     properties set.
+ * @property string  $announcedVersion The most last EAS supported versions
+ *                                     announced to the device.
+ * @property integer $multiplex        Bitmask describing collections that this
+ *                                     device does not support user created
+ *                                     folders for, therefore all sources must
+ *                                     be multiplexed together. Masks are
+ *                                     the MULTIPLEX_* constants.
+ * @property boolean $blocked          True if device has been marked as
+ *                                     blocked.
  *
  */
 class Horde_ActiveSync_Device
@@ -278,6 +281,11 @@ class Horde_ActiveSync_Device
             return true;
         }
 
+        // Don't attempt to provision the Microsoft Connectivity Analyser
+        if ($this->deviceType === 'TestActiveSyncConnectivity') {
+            return true;
+        }
+
         return false;
     }
 
@@ -744,6 +752,11 @@ class Horde_ActiveSync_Device
                 return;
             }
 
+            // Newer GMAIL applications may not send the self::OS value.
+            if (strpos($this->userAgent, 'Android-Mail/7.5') !== false) {
+                $this->_properties['properties'][SELF::MULTIPLEX] = 0;
+                return;
+            }
             // All android before 4.4 KitKat requires multiplex. KitKat and
             // Android 5 native supports non-multiplexed calendars only.
             if (!empty($this->properties[self::OS]) &&
@@ -784,7 +797,7 @@ class Horde_ActiveSync_Device
             // OL2013 and OL2016 do not support multiple contact lists.
             $this->_properties['properties'][self::MULTIPLEX] = Horde_ActiveSync_Device::MULTIPLEX_CONTACTS;
         } else {
-            $this->_properties['properties']['multiplex'] = 0;
+            $this->_properties['properties'][self::MULTIPLEX] = 0;
         }
     }
 
