@@ -463,6 +463,24 @@ abstract class Horde_ActiveSync_Driver_Base
         }
     }
 
+    /**
+     * Return if the specified folder is a special folder.
+     *
+     * @param string $server_id  The server id of the folder.
+     *
+     * @return  True if $server_id is a special folder, otherwise false.
+     */
+    protected function _isSpecialMailbox($server_id)
+    {
+        $folder = $this->getFolder($server_id);
+        return in_array($folder->type, array(
+                Horde_ActiveSync::FOLDER_TYPE_INBOX,
+                Horde_ActiveSync::FOLDER_TYPE_DRAFTS,
+                Horde_ActiveSync::FOLDER_TYPE_WASTEBASKET,
+                Horde_ActiveSync::FOLDER_TYPE_SENTMAIL,
+                Horde_ActiveSync::FOLDER_TYPE_OUTBOX));
+    }
+
     /**
      * Return the SyncStamp - the value used to determine the end of the current
      * sync range. Default implementation uses timestamps. Concrete drivers
@@ -569,7 +587,8 @@ abstract class Horde_ActiveSync_Driver_Base
      * Get a list of server changes that occured during the specified time
      * period.
      *
-     * @param string $folderId     The server id of the collection to check.
+     * @param Horde_ActiveSync_Folder_Base $folder
+     *      The ActiveSync folder object to request changes for.
      * @param integer $from_ts     The starting timestamp.
      * @param integer $to_ts       The ending timestamp.
      * @param integer $cutoffdate  The earliest date to retrieve back to.
@@ -583,6 +602,11 @@ abstract class Horde_ActiveSync_Driver_Base
      * @return array A list of messge uids that have chnaged in the specified
      *               time period.
      *
+     * @throws  Horde_Exception_AuthenticationFailure  Thrown when the
+     *          requested collection appears to be no longer available. For H6,
+     *          we should have the application APIs be responsible for
+     *          differentiating between deleted/not-visible.
+     *
      * @todo Horde 6
      * - Change return structure to (optionally) include the actual $to_ts value
      *   that was used. This is needed because if using something like
@@ -595,7 +619,7 @@ abstract class Horde_ActiveSync_Driver_Base
      *   sent.
      */
     abstract public function getServerChanges(
-        $folderId, $from_ts, $to_ts, $cutoffdate, $ping);
+        $folder, $from_ts, $to_ts, $cutoffdate, $ping);
 
     /**
      * Get a message stat.
