@@ -5,7 +5,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2012-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2012-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -21,7 +21,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2012-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2012-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  *
@@ -59,14 +59,21 @@ class Horde_ActiveSync_Imap_Message
      *
      * @var boolean
      */
-    protected $_lastBodyPartDecode = null;
+    protected $_lastBodyPartDecode;
 
     /**
      * Flag to indicate if this message contains attachments.
      *
      * @var boolean
      */
-    protected $_hasAttachments = null;
+    protected $_hasAttachments;
+
+    /**
+     * Local cache of MessageBodyData object.
+     *
+     * @var Horde_ActiveSync_Imap_MessageBodyData
+     */
+    protected $_mbd;
 
     /**
      * Constructor
@@ -244,6 +251,7 @@ class Horde_ActiveSync_Imap_Message
      * @return array  An array of one or both of 'plain' and 'html' content.
      *
      * @throws Horde_ActiveSync_Exception, Horde_Exception_NotFound
+     * @deprecated - no longer used and will be removed in Horde 6.
      */
     public function getMessageBodyData(array $options = array())
     {
@@ -270,14 +278,18 @@ class Horde_ActiveSync_Imap_Message
      */
     public function getMessageBodyDataObject(array $options = array())
     {
-        return new Horde_ActiveSync_Imap_MessageBodyData(
-            array(
-                'imap' => $this->_imap,
-                'mbox' => $this->_mbox,
-                'uid' => $this->uid,
-                'mime' => $this->basePart),
-            $options
-        );
+        if (empty($this->_mbd)) {
+           $this->_mbd = new Horde_ActiveSync_Imap_MessageBodyData(
+                array(
+                    'imap' => $this->_imap,
+                    'mbox' => $this->_mbox,
+                    'uid' => $this->uid,
+                    'mime' => $this->basePart),
+                $options
+            );
+        }
+
+        return $this->_mbd;
     }
 
     /**
@@ -367,8 +379,7 @@ class Horde_ActiveSync_Imap_Message
             return false;
         }
 
-        reset($tnef_data);
-        while (list(,$data) = each($tnef_data)) {
+        foreach ($tnef_data as $data) {
             $tmp_part = new Horde_Mime_Part();
             $tmp_part->setName($data['name']);
             $tmp_part->setDescription($data['name']);
