@@ -18,7 +18,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2012-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2012-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -30,7 +30,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2012-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2012-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  * @internal
@@ -66,11 +66,7 @@ class Horde_ActiveSync_Request_MoveItems extends Horde_ActiveSync_Request_Base
      */
     protected function _handle()
     {
-        $this->_logger->info(sprintf(
-            '[%s] Handling MoveItems command.',
-            $this->_procid)
-        );
-
+        $this->_logger->meta('Handling MoveItems command.');
         if (!$this->_decoder->getElementStartTag(self::MOVES)) {
             throw new Horde_ActiveSync_Exception('Protocol Error');
         }
@@ -162,4 +158,4 @@ class Horde_ActiveSync_Request_MoveItems extends Horde_ActiveSync_Request_Base
         return true;
     }
 
-}
\ No newline at end of file
+}
