@@ -345,9 +345,6 @@ class Horde_ActiveSync_Request_Sync extends Horde_ActiveSync_Request_SyncBase
                 // iOS need this in order to catch missing state.
                 $this->_logger->err($e->getMessage());
                 $statusCode = self::STATUS_FOLDERSYNC_REQUIRED;
-            } catch (Horde_ActiveSync_Exception_StaleState $e) {
-                $this->_logger->notice($e->getMessage());
-                return false;
             } catch (Horde_ActiveSync_Exception $e) {
                 $this->_logger->err($e->getMessage());
                 return false;
@@ -605,6 +602,12 @@ class Horde_ActiveSync_Request_Sync extends Horde_ActiveSync_Request_SyncBase
     /**
      * Helper method for parsing incoming SYNC_FOLDERS nodes.
      *
+     * @return  boolean  False if any errors were encountered and handled.
+     *                   Otherwise, true.
+     *
+     * @throws  Horde_ActiveSync_Exception when an error cannot be handled
+     *          gracefully, and thus not able to send status code to client.
+     *
      */
     protected function _parseSyncFolders()
     {
@@ -778,10 +781,6 @@ class Horde_ActiveSync_Request_Sync extends Horde_ActiveSync_Request_SyncBase
                 $this->_statusCode = self::STATUS_NOTFOUND;
                 $this->_handleError($collection);
                 return false;
-            } catch (Horde_ActiveSync_Exception $e) {
-                $this->_statusCode = self::STATUS_SERVERERROR;
-                $this->_handleError($collection);
-                return false;
             }
 
             if (!empty($collection['importedchanges'])) {
